@@ -382,7 +382,8 @@ mod_error_info_common_print (sal_log_mod_error_info_t *info, void *common_check_
 static void
 cache_check_info_print (int i, sal_log_mod_error_info_t *cache_check_info)
 {
-	pal_cache_check_info_t *info = (pal_cache_check_info_t *)&cache_check_info->check_info;
+	pal_mc_error_info_t check_info = { cache_check_info->check_info };
+	pal_cache_check_info_t *info = &check_info.pme_cache;
 	static const char * const op[] = {
 		"Unknown/unclassified",			/*  0 */
 		"Load",
@@ -437,7 +438,8 @@ static void
 tlb_check_info_print (int i, sal_log_mod_error_info_t *tlb_check_info)
 
 {
-	pal_tlb_check_info_t *info = (pal_tlb_check_info_t *)&tlb_check_info->check_info;
+	pal_mc_error_info_t check_info = { tlb_check_info->check_info };
+	pal_tlb_check_info_t *info = &check_info.pme_tlb;
 	static const char * const op[] = {
 		"Unknown/unclassified",			/*  0 */
 		"Load",
@@ -480,7 +482,8 @@ tlb_check_info_print (int i, sal_log_mod_error_info_t *tlb_check_info)
 static void
 bus_check_info_print (int i, sal_log_mod_error_info_t *bus_check_info)
 {
-	pal_bus_check_info_t *info = (pal_bus_check_info_t *)&bus_check_info->check_info;
+	pal_mc_error_info_t check_info = { bus_check_info->check_info };
+	pal_bus_check_info_t *info = &check_info.pme_bus;
 	static const char * const type[] = {
 		"Unknown/unclassified",			/*  0 */
 		"Partial read",
@@ -533,7 +536,8 @@ bus_check_info_print (int i, sal_log_mod_error_info_t *bus_check_info)
 static void
 reg_file_check_info_print (int i, sal_log_mod_error_info_t *reg_file_check_info)
 {
-	pal_reg_file_check_info_t *info = (pal_reg_file_check_info_t *)&reg_file_check_info->check_info;
+	pal_mc_error_info_t check_info = { reg_file_check_info->check_info };
+	pal_reg_file_check_info_t *info = &check_info.pme_reg_file;
 	static const char * const id[] = {
 		"Unknown/unclassified",			/*  0 */
 		"General register (bank 1)",
@@ -580,7 +584,8 @@ reg_file_check_info_print (int i, sal_log_mod_error_info_t *reg_file_check_info)
 static void
 ms_check_info_print (int i, sal_log_mod_error_info_t *ms_check_info)
 {
-	pal_uarch_check_info_t *info = (pal_uarch_check_info_t *)&ms_check_info->check_info;
+	pal_mc_error_info_t check_info = { ms_check_info->check_info };
+	pal_uarch_check_info_t *info = &check_info.pme_uarch;
 	static const char * const array_id[] = {
 		"Unknown/unclassified",
 	};
@@ -928,10 +933,12 @@ static void
 proc_summary (sal_log_processor_info_t *slpi)
 {
 	const char *label, *summary = NULL;
-	pal_processor_state_info_t *sp = (pal_processor_state_info_t *)(&slpi->proc_state_parameter);
+	pal_mc_error_info_t psp = { slpi->proc_state_parameter };
+	pal_processor_state_info_t *sp = &psp.pme_processor;
 	sal_log_mod_error_info_t *bus_info = slpi->info + slpi->valid.num_cache_check + slpi->valid.num_tlb_check;
-	pal_bus_check_info_t *bus_check_info = (pal_bus_check_info_t *)
-		(slpi->valid.num_bus_check && bus_info->valid.check_info ? &bus_info->check_info : NULL);
+	pal_mc_error_info_t check_info = { bus_info->check_info };
+	pal_bus_check_info_t *bus_check_info =
+		(slpi->valid.num_bus_check && bus_info->valid.check_info ? &check_info.pme_bus : NULL);
 	if (sp->cc)
 		summary = "Cache Check";
 	else if (sp->tc)
@@ -962,21 +969,10 @@ proc_summary (sal_log_processor_info_t *slpi)
 	iprintf("%s: %s\n", label, summary);
 }
 
-/* Decode the processor LID field */
-
-#define lid_to_slice(lid) (((lid) >> 28) & 0xf)
-#define lid_to_nasid(lid) (((lid) >> 16) & 0xfff)
-
 static void
 proc_decode_lid (sal_log_processor_info_t *slpi)
 {
 	prval("processor lid", slpi->proc_cr_lid);
-	++indent;
-	/* FIXME: SN specific.  Need a generic way to decode lid */
-	iprintf("cpu: %c nasid: 0x%lx\n",
-		(char)(lid_to_slice(slpi->proc_cr_lid) + 'A'),
-		lid_to_nasid(slpi->proc_cr_lid));
-	--indent;
 }
 
 /* Decode one level sensitive field from the error map */
@@ -1417,7 +1413,7 @@ proc_dev_err_info_print (sal_log_processor_info_t *slpi)
 		char    *p_data = (char *)&slpi->valid;
 		iprintf("SAL_PROC_DEV_ERR SECTION DATA:  Data buffer = %p, "
 		       "Data size = %ld\n", (void *)p_data, d_len);
-		hexdump(p_data, d_len);
+		hexdump((unsigned char *)p_data, d_len);
 		iprintf("End of SAL_PROC_DEV_ERR SECTION DATA\n");
 	}
 
@@ -1535,7 +1531,7 @@ platform_info_print (sal_log_record_header_t *lh, int use_sal, int fd_data, int
 				char    *p_data = (char *)&((sal_log_mem_dev_err_info_t *)slsh)->valid;
 				iprintf("Start of Platform Err Data Section:  Data buffer = %p, "
 				       "Data size = %ld\n", (void *)p_data, d_len);
-				hexdump(p_data, d_len);
+				hexdump((unsigned char *)p_data, d_len);
 				iprintf("End of Platform Err Data Section\n");
 			}
 		}
